<?php
/**
 * 近期评论小工具
 */

class pixart_widget_recent_comments extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'widget_pixart_recent_comments',
			'description' => 'PixArt小工具 - 近期评论',
			'name'        => 'PixArt - 近期评论'
		);
		parent::__construct(false, false, $widget_ops);
	}

	function form($instance) {	
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of comments to show:' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = absint( $new_instance['number'] );
		return $instance;
	}

	function widget($args, $instance) {
		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Comments' );
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;

		$comments = get_comments( apply_filters( 'widget_comments_args', array(
			'number'      => $number,
			'status'      => 'approve',
			'post_status' => 'publish',
			'type' => 'comment',
			'user_id' => 0
		), $instance ) );

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . $title . $args['after_title'];
		}

		$output .= '<ul id="recentcomments">';
		if ( is_array( $comments ) && $comments ) {
			$post_ids = array_unique( wp_list_pluck( $comments, 'comment_post_ID' ) );
			_prime_post_caches( $post_ids, strpos( get_option( 'permalink_structure' ), '%category%' ), false );

			foreach ( (array) $comments as $comment ) {
				$output .= '<li class="recentcomments">';
				$t1=get_comment_date("Y-m-d H:i:s", $comment); 
				$t2=date("Y-m-d H:i:s"); 	
				$diff = strtotime($t2)-strtotime($t1);
				$zf_time = '';

				if ($zf_time = floor($diff/86400)) {
					$zf_time .= '天';
				} elseif ($zf_time = floor($diff/3600)) {
					$zf_time .= '小时';
				} elseif ($zf_time = floor($diff/60)) {
					$zf_time .= '分钟';
				} else {
					$zf_time = $diff . '秒';
				}

				$output .= sprintf( _x( '%1$s : %2$s', 'widgets' ),
					'<a href="' . esc_url( get_comment_link( $comment ) ) . '">' . get_avatar(get_comment_author_email($comment), 50) . '<span class="comment-author-link"><b>' . mb_strimwidth(get_comment_author( $comment ), 0, 20). '</b> ' . $zf_time . '前说',
					mb_strimwidth(strip_tags($comment->comment_content), 0, 100, "...") . '</span></a>'
				);
				$output .= '</li>';
			}
		}
		$output .= '</ul>';
		$output .= $args['after_widget'];

		echo $output;
	}

}